@@ -83,7 +83,9 @@ def get_or_fetch_tourney_ids() -> Set[str]:
         tournaments = get_tournament_ids(org)
         if tournaments:
             for t in tournaments:
-                tournament_info = get_tourney_teams_file(t)
-                if tournament_info and tournament_info[0].get("gameName") == "Splatoon 2":
-                    result.add(t)
+                tournament_info = get_tourney_info_file(t)
+                if tournament_info:
+                    name = tournament_info.get("gameName")
+                    if name.startswith("Splatoon"):
+                        result.add(t)
     return result
